# B2A
同步百度云网盘到阿里云

## 📺 安装 

```shell
pip3 install b2a --upgrade
```

## 🤖 功能

- 登录百度云盘
- 登录阿里云盘
- 迁移文件
- 显示目录

## 💽 界面

![](https://raw.githubusercontent.com/yaronzz/BaiduYunToAliYun/main/image/1.png)

## 🎄使用

1. 登录阿里云，需要获取`refresh_token`

![](https://raw.githubusercontent.com/yaronzz/BaiduYunToAliYun/main/image/2.png)

2. 登录百度云，需要获取`cookies`

![](https://raw.githubusercontent.com/yaronzz/BaiduYunToAliYun/main/image/3.png)
